@@ -71,15 +71,21 @@ def resolve_dependencies(request):
             filename=filename, content=_get_xsd_content_from_html(xsd_content)
         )
         init_template_with_dependencies(
-            type_object, _get_dependencies_dict(schema_locations, dependencies)
+            type_object,
+            _get_dependencies_dict(schema_locations, dependencies),
+            request=request,
         )
 
         # get the version manager or create a new one
         if version_manager_id != "":
-            type_version_manager = version_manager_api.get(version_manager_id)
+            type_version_manager = version_manager_api.get(
+                version_manager_id, request=request
+            )
         else:
             type_version_manager = TypeVersionManager(title=name)
-        type_version_manager_api.insert(type_version_manager, type_object, buckets)
+        type_version_manager_api.insert(
+            type_version_manager, type_object, request=request, list_bucket_ids=buckets
+        )
     except Exception as e:
         return HttpResponseBadRequest(
             escape(str(e)), content_type="application/javascript"
